@@ -1,17 +1,18 @@
 /*
- * smartcalc v1.0.5
+ * smartcalc v1.0.7
  * Copyright (c) Erhan BARIS (Ruslan Ognyanov Asenov)
  * Licensed under the GNU General Public License v2.0.
  */
 
 use crate::SmartCalc;
+use crate::Session;
 use crate::compiler::date::DateItem;
 use crate::compiler::duration::DurationItem;
-use crate::compiler::memory::MemoryItem;
+use crate::compiler::dynamic_type::DynamicTypeItem;
 use crate::compiler::time::TimeItem;
 use crate::config::SmartCalcConfig;
 use crate::compiler::money::MoneyItem;
-use crate::types::{SmartCalcAstType, MemoryType, TimeOffset};
+use crate::types::{SmartCalcAstType, TimeOffset};
 use chrono::{Duration, NaiveDate, Utc};
 use chrono::{Datelike};
 use alloc::string::ToString;
@@ -588,10 +589,13 @@ fn execute_33() {
     match results.lines[0].as_ref().unwrap().result.as_ref().unwrap().ast.deref() {
         SmartCalcAstType::Item(item) => {
             assert_eq!(item.get_underlying_number(), 1048.0);
-            match item.as_any().downcast_ref::<MemoryItem>() {
+            match item.as_any().downcast_ref::<DynamicTypeItem>() {
                 Some(memory_item) => {
-                    assert_eq!(memory_item.get_memory(), 1048.0);
-                    assert_eq!(memory_item.get_memory_type(), MemoryType::MegaByte);
+                    assert_eq!(memory_item.get_number(), 1048.0);
+
+                    let type_detail = memory_item.get_type();
+                    assert_eq!(&type_detail.group_name[..], "memory");
+                    assert_eq!(type_detail.index, 4);
                 },
                 _ => assert!(false)
             };
@@ -633,9 +637,9 @@ fn execute_35() {
     match results.lines[0].as_ref().unwrap().result.as_ref().unwrap().ast.deref() {
         SmartCalcAstType::Item(item) => {
             match item.as_any().downcast_ref::<TimeItem>() {
-                Some(memory_item) => {
-                    assert_eq!(memory_item.get_tz(), TimeOffset { name: "CET".to_string(), offset: 60 } );
-                    assert_eq!(memory_item.get_time(), chrono::Utc::today().and_hms(16, 0, 0).naive_utc());
+                Some(time_item) => {
+                    assert_eq!(time_item.get_tz(), TimeOffset { name: "CET".to_string(), offset: 60 } );
+                    assert_eq!(time_item.get_time(), chrono::Utc::today().and_hms(16, 0, 0).naive_utc());
                 },
                 _ => assert!(false)
             };
@@ -643,3 +647,107 @@ fn execute_35() {
         _ => assert!(false)
     };
 }
+
+#[test]
+fn execute_36() {
+    let test_data = r"=".to_string();
+    let calculater = SmartCalc::default();
+    let results = calculater.execute("en".to_string(), test_data);
+    
+    assert_eq!(results.status, true);
+    assert_eq!(results.lines.len(), 1);
+    assert_eq!(results.lines[0].is_some(), true);
+    assert_eq!(results.lines[0].as_ref().unwrap().result.is_err(), true);
+}
+
+#[test]
+fn execute_37() {
+    let test_data = r"a=".to_string();
+    let calculater = SmartCalc::default();
+    let results = calculater.execute("en".to_string(), test_data);
+    
+    assert_eq!(results.status, true);
+    assert_eq!(results.lines.len(), 1);
+    assert_eq!(results.lines[0].is_some(), true);
+    assert_eq!(results.lines[0].as_ref().unwrap().result.is_err(), true);
+}
+
+#[test]
+fn execute_38() {
+    let test_data = r"=1".to_string();
+    let calculater = SmartCalc::default();
+    let results = calculater.execute("en".to_string(), test_data);
+    
+    assert_eq!(results.status, true);
+    assert_eq!(results.lines.len(), 1);
+    assert_eq!(results.lines[0].is_some(), true);
+    assert_eq!(results.lines[0].as_ref().unwrap().result.is_err(), true);
+}
+
+macro_rules! evaluate_line {
+    ($calc:ident, $input:literal => Err) => {
+        let res = $calc.execute("en".to_string(), $input.to_string());
+        assert_eq!(res.lines.len(), 1);
+        assert!(res.lines[0].as_ref().unwrap().result.as_ref().is_err());
+    };
+    ($calc:ident, $input:literal => $output:literal) => {
+        let res = $calc.execute("en".to_string(), $input.to_string());
+        assert_eq!(res.lines.len(), 1);
+        let output: &str = res.lines[0]
+            .as_ref()
+            .unwrap()
+            .result
+            .as_ref()
+            .unwrap()
+            .output
+            .as_ref();
+        assert_eq!(output, $output);
+    };
+    ($calc:ident with $session:ident, $input:literal => Err) => {
+        $session.set_text($input.to_string());
+        let res = $calc.execute_session(&$session);
+        assert_eq!(res.lines.len(), 1);
+        assert!(res.lines[0].as_ref().unwrap().result.as_ref().is_err());
+    };
+    ($calc:ident with $session:ident, $input:literal => $output:literal) => {
+        $session.set_text($input.to_string());
+        let res = $calc.execute_session(&$session);
+        assert_eq!(res.lines.len(), 1);
+        let output: &str = res.lines[0]
+            .as_ref()
+            .unwrap()
+            .result
+            .as_ref()
+            .unwrap()
+            .output
+            .as_ref();
+        assert_eq!(output, $output);
+    };
+}
+
+#[test]
+fn execute_session() {
+    let calc = SmartCalc::default();
+
+    // standard evaluation always uses a new session
+    evaluate_line!(calc, r"foo = 1" => r"1");
+    evaluate_line!(calc, r"bar = 2" => r"2");
+    evaluate_line!(calc, r"foo + bar" => Err);
+
+    let mut session = Session::new();
+    session.set_language("en".to_string());
+
+    // persistent session should keep variables from previous evaluations
+    evaluate_line!(calc with session, r"foo = 1" => r"1");
+    evaluate_line!(calc with session, r"bar = 2" => r"2");
+    evaluate_line!(calc with session, r"foo + bar" => r"3");
+
+    // rebinding a variable should work too
+    evaluate_line!(calc with session, r"foo = 10" => r"10");
+    evaluate_line!(calc with session, r"foo + bar" => r"12");
+
+    // opening a new session should clear any previously set variables
+    let mut session = Session::new();
+    session.set_language("en".to_string());
+    evaluate_line!(calc with session, r"foo + bar" => Err);
+}
